read_with_padding

Function read_with_padding 

pub fn read_with_padding(file: &mut File, buffer: &mut [u8]) -> Result<()>
Reads the file into the buffer until the buffer is full or the EOF is reached.

If it reaches the EOF before the buffer is full pad the buffer with zeros.